﻿using PolyBeam.Connector;
using PolyBeam.DataModels;
using PolyBeam.DataModels.Concrete;
using PolyBeam.DataModels.Loads;
using PolyBeam.DataModels.Results;
using PolyBeam.DataModels.Supports;

// Add supports
List<Support> supports = new List<Support>();
supports.Add(new Support()
{
    Location = 0,   
    DisplacementY = new SupportCondition() { Type = SupportConditionType.Fixed },
    DisplacementZ = new SupportCondition() { Type = SupportConditionType.Fixed },
    RotationX = new SupportCondition() { Type = SupportConditionType.Fixed },
});
supports.Add(new Support()
{
    Location = 5,
    DisplacementY = new SupportCondition() { Type = SupportConditionType.Fixed },
    DisplacementZ = new SupportCondition() { Type = SupportConditionType.Fixed },
    RotationX = new SupportCondition() { Type = SupportConditionType.Fixed },
});

// Add Loads
List<DistributedLoad> distributedLoads = new List<DistributedLoad>();
distributedLoads.Add(new DistributedLoad()
{
    StartLocation = 0,
    EndLocation = 5,
    StartLoad = 10000,
    EndLoad = 10000,
});

List<LoadCase> loadCases = new List<LoadCase>();
loadCases.Add(new LoadCase()
{
    Name = "Load Case 1",
    IncludeSelfWeight = true,
    DistributedLoads = distributedLoads,
});

// Add Cross Section
RectangularConcreteBeamProperties concreteSection = new RectangularConcreteBeamProperties()
{
    Concrete = new ConcreteMaterial() { Name = "C12", AggregateSize = 0.032 },
    LongitudinalReinforcement = new ReinforcementMaterial() { Name = "Y" },
    Depth = 0.4,
    Width = 0.2,
    CoverBottom = 0.03,
    CoverTop = 0.03,
    CoverSides = 0.03,
    BottomRebarLayers = new List<RebarLayer>() { new RebarLayer() { Diameter = 0.016, NumberOfRebars = 3 } },
    TopRebarLayers = new List<RebarLayer>() { new RebarLayer() { Diameter = 0.016, NumberOfRebars = 2 } },
    Stirrups = new Stirrups() { Diameter = 0.006, Spacing = 0.2 },
};

PolyBeamDataModel polyBeamDataModel = new PolyBeamDataModel()
{
    FireSettings = null,
    LoadGroups = null,
    LoadCases = loadCases,
    Supports = supports,
    ULSLoadCombinations = null,
    SLSLoadCombinations = null,
    FireLoadCombinations = null,
    BeamProperties = new BeamProperties() { BeamType = BeamType.RectangularConcreteBeam, RectangularConcreteBeamProperties = concreteSection },
    DesignSettings = null,
    BucklingSettings = null,
    DocumentationSettings = null,
    Hinges = null,
};

// Do Calculation
using (var polyBeam = new PolyBeamConnection())
{
    PolyBeamDataModelResult? polyBeamDataModelResult = polyBeam.Calculate(polyBeamDataModel);
    if (polyBeamDataModelResult?.ULSUtilization != null) Console.WriteLine($"ULS utilization: {polyBeamDataModelResult.ULSUtilization}");
    else Console.WriteLine("Calculation failed.");

    polyBeam?.CloseApplication();
}

// Save to file 
string userProfile = Environment.GetFolderPath(Environment.SpecialFolder.UserProfile);
string downloadsPath = Path.Combine(userProfile, "Downloads");
string filePath = Path.Combine(downloadsPath, "Example1 - SimpleConcreteBeam.pb2");

Console.WriteLine($"File will be saved to save file to {filePath}");

FileAccessService.SaveModelToFile(polyBeamDataModel, filePath);

Console.WriteLine("Press any key to exit.");
Console.ReadKey();