﻿using PolyBeam.Connector;
using PolyBeam.DataModels;

Console.WriteLine("All .pb2 files within the directory path will be calculated and saved as pdf");
Console.WriteLine("Please enter a directory path:");

string? directoryPath = Console.ReadLine();

if (!Directory.Exists(directoryPath))
{
    Console.WriteLine("The directory does not exist. Press any key to exit.");
    Console.ReadKey();
    return;
}

string[] pb2Files = Directory.GetFiles(directoryPath, "*.pb2");
// If no files are found, inform the user.
if (pb2Files.Length == 0)
{
    Console.WriteLine("No .pb2 files found in the directory.");
    Console.WriteLine("The directory does not exist. Press any key to exit.");
    Console.ReadKey();
    return;
}
else
{
    using (var polyBeam = new PolyBeamConnection())
    {
        foreach (var pb2File in pb2Files)
        {
            string pdfFileName = Path.ChangeExtension(pb2File, ".pdf");
            PolyBeamDataModel? polyBeamDataModel = FileAccessService.LoadModelFromFile(pb2File);

            try
            {
                bool success = polyBeam.SavePDF(polyBeamDataModel, pdfFileName);
                if (success == true)
                {
                    Console.WriteLine($"PDF file has been saved. {pdfFileName}");
                    continue;
                }
            }
            catch (Exception)
            {
                Console.WriteLine($"PDF file has not been saved. {pdfFileName}");
            }
        }

        polyBeam?.CloseApplication();
    }

    Console.WriteLine("Press any key to exit.");
    Console.ReadKey();
}

